aboutsummaryrefslogtreecommitdiff
path: root/engines/mohawk/myst_state.h
diff options
context:
space:
mode:
authorBastien Bouclet2011-01-09 10:14:40 +0000
committerBastien Bouclet2011-01-09 10:14:40 +0000
commit9265c85c4967fa3ae3efba1ca5fe0f315237052a (patch)
tree97e7e365b7242f4a666de97755829b1fe2d90dad /engines/mohawk/myst_state.h
parentcf94a99bb7551e8338d4d127094295deec1d489d (diff)
downloadscummvm-rg350-9265c85c4967fa3ae3efba1ca5fe0f315237052a.tar.gz
scummvm-rg350-9265c85c4967fa3ae3efba1ca5fe0f315237052a.tar.bz2
scummvm-rg350-9265c85c4967fa3ae3efba1ca5fe0f315237052a.zip
MOHAWK: Implement minimal D'ni stack. Lacking movie control.
svn-id: r55180
Diffstat (limited to 'engines/mohawk/myst_state.h')
-rw-r--r--engines/mohawk/myst_state.h24
1 files changed, 9 insertions, 15 deletions
diff --git a/engines/mohawk/myst_state.h b/engines/mohawk/myst_state.h
index 2787efac4f..400f379502 100644
--- a/engines/mohawk/myst_state.h
+++ b/engines/mohawk/myst_state.h
@@ -64,9 +64,10 @@ public:
uint16 heldPage;
uint16 u1;
uint16 transitions;
- uint16 ending;
+ uint16 zipMode;
uint16 redPagesInBook;
uint16 bluePagesInBook;
+ uint16 ending;
} _globals;
/* 50 Myst Specific Variables :
@@ -268,24 +269,17 @@ public:
uint16 generatorPowerLevel[5];
} _stoneship;
- /* 1 Dunny Specific Variable :
- 0 = Outcome State
- */
- struct Dni {
- uint16 outcomeState;
- } _dni;
-
- // The values in these regions seem to be lists of resource IDs
- // which correspond to VIEW resources i.e. cards
- uint16 unknownMyst[31];
+ // The values in these regions are lists of VIEW resources
+ // which correspond to visited zip destinations
+ uint16 mystReachableZipDests[41];
- uint16 unknownChannelwood[37];
+ uint16 channelwoodReachableZipDests[41];
- uint16 unknownMech[18];
+ uint16 mechReachableZipDests[41];
- uint16 unknownSelenitic[30];
+ uint16 seleniticReachableZipDests[41];
- uint16 unknownStoneship[22];
+ uint16 stoneshipReachableZipDests[41];
private:
void syncGameState(Common::Serializer &s, bool isME);